@@ -227,8 +227,8 @@ pub(crate) struct PruneOptions {
 }
 
 pub(crate) fn auto_prune() -> Result<()> {
-    if rand::random::<u8>() % 10 != 0 {
-        return Ok(()); // only prune 10% of the time
+    if rand::random::<u8>() % 100 != 0 {
+        return Ok(()); // only prune 1% of the time
     }
     let settings = Settings::get();
     let age = match settings.cache_prune_age_duration() {
@@ -311,7 +311,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_cache() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         let cache = CacheManagerBuilder::new(dirs::CACHE.join("test-cache")).build();
         cache.clear().unwrap();
         let val = cache.get_or_try_init(|| Ok(1)).unwrap();
