@@ -319,7 +319,6 @@ impl Commands {
 }
 
 impl Cli {
-    #[async_backtrace::framed]
     pub async fn run(args: &Vec<String>) -> Result<()> {
         crate::env::ARGS.write().unwrap().clone_from(args);
         measure!("logger", { logger::init() });
@@ -353,7 +352,7 @@ impl Cli {
             Ok(cmd)
         } else {
             if let Some(task) = self.task {
-                let config = Config::get().await;
+                let config = Config::get().await?;
                 if config.tasks().await?.iter().any(|(_, t)| t.is_match(&task)) {
                     return Ok(Commands::Run(run::Run {
                         task,
