@@ -23,9 +23,7 @@ use crate::env::{MISE_DEFAULT_CONFIG_FILENAME, MISE_DEFAULT_TOOL_VERSIONS_FILENA
 use crate::file::display_path;
 use crate::shorthands::{Shorthands, get_shorthands};
 use crate::task::Task;
-use crate::toolset::{
-    ToolRequestSet, ToolRequestSetBuilder, ToolVersion, Toolset, ToolsetBuilder, install_state,
-};
+use crate::toolset::{ToolRequestSet, ToolRequestSetBuilder, ToolVersion, Toolset, install_state};
 use crate::ui::style;
 use crate::{backend, dirs, env, file, lockfile, registry, runtime_symlinks, shims, timeout};
 use crate::{backend::ABackend, cli::version::VERSION};
@@ -44,7 +42,6 @@ use crate::plugins::PluginType;
 use crate::tera::BASE_CONTEXT;
 use crate::watch_files::WatchFile;
 use crate::wildcard::Wildcard;
-pub use settings::SETTINGS;
 
 type AliasMap = IndexMap<String, Alias>;
 type ConfigMap = IndexMap<PathBuf, Arc<dyn ConfigFile>>;
@@ -81,25 +78,34 @@ pub fn is_loaded() -> bool {
 }
 
 impl Config {
-    pub async fn get() -> Arc<Self> {
-        Self::try_get().await.unwrap()
+    pub async fn get() -> Result<Arc<Self>> {
+        if let Some(config) = &*_CONFIG.read().unwrap() {
+            return Ok(config.clone());
+        }
+        measure!("load config", { Self::load().await })
     }
     pub fn get_() -> Arc<Self> {
         (*_CONFIG.read().unwrap()).clone().unwrap()
     }
-    pub async fn try_get() -> Result<Arc<Self>> {
-        if let Some(config) = &*_CONFIG.read().unwrap() {
-            return Ok(config.clone());
-        }
-        let config = measure!("load config", { Arc::new(Self::load().await?) });
-        *_CONFIG.write().unwrap() = Some(config.clone());
-        Ok(config)
+    pub async fn reset() -> Result<Arc<Self>> {
+        backend::reset().await?;
+        timeout::run_with_timeout_async(
+            async || {
+                _CONFIG.write().unwrap().take();
+                *GLOBAL_CONFIG_FILES.lock().unwrap() = None;
+                *SYSTEM_CONFIG_FILES.lock().unwrap() = None;
+                GLOB_RESULTS.lock().unwrap().clear();
+                Ok(())
+            },
+            Duration::from_secs(5),
+        )
+        .await?;
+        Config::load().await
     }
+
     #[async_backtrace::framed]
-    pub async fn load() -> Result<Self> {
-        measure!("config::load reset", {
-            reset().await?;
-        });
+    pub async fn load() -> Result<Arc<Self>> {
+        backend::load_tools().await?;
         let idiomatic_files = measure!("config::load idiomatic_files", {
             load_idiomatic_files().await
         });
@@ -124,7 +130,7 @@ impl Config {
             config_files,
             env: OnceCell::new(),
             env_with_sources: OnceCell::new(),
-            shorthands: get_shorthands(&SETTINGS),
+            shorthands: get_shorthands(&Settings::get()),
             hooks: OnceCell::new(),
             tasks: OnceCell::new(),
             tool_request_set: OnceCell::new(),
@@ -211,6 +217,8 @@ impl Config {
             }
         });
 
+        let config = Arc::new(config);
+        *_CONFIG.write().unwrap() = Some(config.clone());
         Ok(config)
     }
     pub fn env_maybe(&self) -> Option<IndexMap<String, String>> {
@@ -232,7 +240,7 @@ impl Config {
         self.env_with_sources
             .get_or_try_init(async || {
                 let mut env = self.env_results().await?.env.clone();
-                for env_file in SETTINGS.env_files() {
+                for env_file in Settings::get().env_files() {
                     match dotenvy::from_path_iter(&env_file) {
                         Ok(iter) => {
                             for item in iter {
@@ -366,7 +374,7 @@ impl Config {
     }
 
     async fn load_all_tasks(&self) -> Result<BTreeMap<String, Task>> {
-        let config = Config::get().await;
+        let config = Config::get().await?;
         time!("load_all_tasks");
         // let (file_tasks, global_tasks, system_tasks) = tokio::join!(
         //     {
@@ -558,7 +566,12 @@ impl Config {
             .flatten()
             .chain(env_results.env_files.iter().map(|p| p.as_path().into()))
             .chain(env_results.env_scripts.iter().map(|p| p.as_path().into()))
-            .chain(SETTINGS.env_files().iter().map(|p| p.as_path().into()))
+            .chain(
+                Settings::get()
+                    .env_files()
+                    .iter()
+                    .map(|p| p.as_path().into()),
+            )
             .collect())
     }
 
@@ -646,10 +659,13 @@ fn get_project_root(config_files: &ConfigMap) -> Option<PathBuf> {
 }
 
 async fn load_idiomatic_files() -> BTreeMap<String, Vec<String>> {
-    if !SETTINGS.idiomatic_version_file {
+    if !Settings::get().idiomatic_version_file {
         return BTreeMap::new();
     }
-    if !SETTINGS.idiomatic_version_file_disable_tools.is_empty() {
+    if !Settings::get()
+        .idiomatic_version_file_disable_tools
+        .is_empty()
+    {
         deprecated!(
             "idiomatic_version_file_disable_tools",
             "is deprecated, use idiomatic_version_file_enable_tools instead"
@@ -657,10 +673,13 @@ async fn load_idiomatic_files() -> BTreeMap<String, Vec<String>> {
     }
     let mut jset = JoinSet::new();
     let tool_is_enabled = |tool: &dyn Backend| {
-        if let Some(enable_tools) = &SETTINGS.idiomatic_version_file_enable_tools {
+        if let Some(enable_tools) = &Settings::get().idiomatic_version_file_enable_tools {
             enable_tools.contains(tool.id())
-        } else if !SETTINGS.idiomatic_version_file_disable_tools.is_empty() {
-            !SETTINGS
+        } else if !Settings::get()
+            .idiomatic_version_file_disable_tools
+            .is_empty()
+        {
+            !Settings::get()
                 .idiomatic_version_file_disable_tools
                 .contains(tool.id())
         } else {
@@ -822,7 +841,7 @@ pub fn config_file_from_dir(p: &Path) -> PathBuf {
             }
         }
     }
-    match SETTINGS.asdf_compat {
+    match Settings::get().asdf_compat {
         true => p.join(&*MISE_DEFAULT_TOOL_VERSIONS_FILENAME),
         false => p.join(&*MISE_DEFAULT_CONFIG_FILENAME),
     }
@@ -1150,23 +1169,23 @@ fn default_task_includes() -> Vec<PathBuf> {
 }
 
 #[async_backtrace::framed]
-pub async fn rebuild_shims_and_runtime_symlinks(new_versions: &[ToolVersion]) -> Result<()> {
-    let config = Arc::new(Config::load().await?);
-    let ts = measure!("build_toolset", {
-        ToolsetBuilder::new().build(&config).await?
-    });
+pub async fn rebuild_shims_and_runtime_symlinks(
+    config: &Arc<Config>,
+    ts: &Toolset,
+    new_versions: &[ToolVersion],
+) -> Result<()> {
     measure!("rebuilding shims", {
-        shims::reshim(&config, &ts, false)
+        shims::reshim(config, ts, false)
             .await
             .wrap_err("failed to rebuild shims")?;
     });
     measure!("rebuilding runtime symlinks", {
-        runtime_symlinks::rebuild(&config)
+        runtime_symlinks::rebuild(config)
             .await
             .wrap_err("failed to rebuild runtime symlinks")?;
     });
     measure!("updating lockfiles", {
-        lockfile::update_lockfiles(&config, &ts, new_versions)
+        lockfile::update_lockfiles(config, ts, new_versions)
             .wrap_err("failed to update lockfiles")?;
     });
 
@@ -1174,7 +1193,7 @@ pub async fn rebuild_shims_and_runtime_symlinks(new_versions: &[ToolVersion]) ->
 }
 
 fn warn_about_idiomatic_version_files(config_files: &ConfigMap) {
-    if SETTINGS
+    if Settings::get()
         .idiomatic_version_file_enable_tools
         .as_ref()
         .is_some()
@@ -1214,22 +1233,6 @@ See https://github.com/jdx/mise/discussions/4345 for more information."#,
     );
 }
 
-async fn reset() -> Result<()> {
-    backend::reset().await?;
-    timeout::run_with_timeout_async(
-        async || {
-            _CONFIG.write().unwrap().take();
-            *GLOBAL_CONFIG_FILES.lock().unwrap() = None;
-            *SYSTEM_CONFIG_FILES.lock().unwrap() = None;
-            GLOB_RESULTS.lock().unwrap().clear();
-            Ok(())
-        },
-        Duration::from_secs(5),
-    )
-    .await?;
-    Ok(())
-}
-
 async fn load_local_tasks(config: &Arc<Config>) -> Result<Vec<Task>> {
     let mut tasks = vec![];
     for d in file::all_dirs()? {
@@ -1326,7 +1329,12 @@ async fn load_tasks_includes(
         .try_collect::<_, Vec<PathBuf>, _>()?
         .into_iter()
         .filter(|p| file::is_executable(p))
-        .filter(|p| !SETTINGS.task_disable_paths.iter().any(|d| p.starts_with(d)))
+        .filter(|p| {
+            !Settings::get()
+                .task_disable_paths
+                .iter()
+                .any(|d| p.starts_with(d))
+        })
         .collect::<Vec<_>>();
     let mut tasks = vec![];
     let root = Arc::new(root.to_path_buf());
@@ -1459,13 +1467,13 @@ mod tests {
 
     #[tokio::test]
     async fn test_load() {
-        let config = Config::load().await.unwrap();
+        let config = Config::reset().await.unwrap();
         assert_debug_snapshot!(config);
     }
 
     #[tokio::test]
     async fn test_load_all_config_files_skips_directories() -> Result<()> {
-        let _config = Config::get().await;
+        let _config = Config::get().await?;
         let temp_dir = TempDir::new()?;
         let temp_path = temp_dir.path();
 
