@@ -3,11 +3,10 @@ use std::fmt::{Display, Formatter};
 use std::path::PathBuf;
 use std::sync::Arc;
 
-use crate::backend::Backend;
 use crate::cli::args::BackendArg;
 use crate::config::Config;
 use crate::config::env_directive::{EnvResolveOptions, EnvResults};
-use crate::config::settings::{SETTINGS, SettingsStatusMissingTools};
+use crate::config::settings::{Settings, SettingsStatusMissingTools};
 use crate::env::{PATH_KEY, TERM_WIDTH};
 use crate::env_diff::EnvMap;
 use crate::errors::Error;
@@ -18,6 +17,7 @@ use crate::registry::tool_enabled;
 use crate::ui::multi_progress_report::MultiProgressReport;
 use crate::uv;
 use crate::{backend, config, env, hooks};
+use crate::{backend::Backend, parallel};
 pub use builder::ToolsetBuilder;
 use console::truncate_str;
 use eyre::{Result, WrapErr};
@@ -98,11 +98,11 @@ pub struct InstallOptions {
 impl Default for InstallOptions {
     fn default() -> Self {
         InstallOptions {
-            jobs: Some(SETTINGS.jobs),
-            raw: SETTINGS.raw,
+            jobs: Some(Settings::get().jobs),
+            raw: Settings::get().raw,
             force: false,
             missing_args_only: true,
-            auto_install_disable_tools: SETTINGS.auto_install_disable_tools.clone(),
+            auto_install_disable_tools: Settings::get().auto_install_disable_tools.clone(),
             resolve_options: Default::default(),
         }
     }
@@ -152,20 +152,24 @@ impl Toolset {
     #[async_backtrace::framed]
     pub async fn resolve(&mut self, config: &Arc<Config>) -> eyre::Result<()> {
         self.list_missing_plugins();
-        let mut tvls = vec![];
-        for (ba, mut tvl) in self.versions.clone().into_iter() {
-            tvl.resolve(config, &Default::default()).await?;
-            tvls.push((ba, tvl));
-        }
-        for (ba, tvl) in tvls {
-            self.versions.insert(ba, tvl);
-        }
+        let versions = self
+            .versions
+            .clone()
+            .into_iter()
+            .map(|(ba, tvl)| (config.clone(), ba, tvl.clone()))
+            .collect::<Vec<_>>();
+        let tvls = parallel::parallel(versions, |(config, ba, mut tvl)| async move {
+            tvl.resolve(&config, &Default::default()).await?;
+            Ok((ba, tvl))
+        })
+        .await?;
+        self.versions = tvls.into_iter().collect();
         Ok(())
     }
     #[async_backtrace::framed]
     pub async fn install_missing_versions(
         &mut self,
-        config: &Arc<Config>,
+        config: &mut Arc<Config>,
         opts: &InstallOptions,
     ) -> Result<Vec<ToolVersion>> {
         let versions = self
@@ -187,7 +191,8 @@ impl Toolset {
             .collect_vec();
         let versions = self.install_all_versions(config, versions, opts).await?;
         if !versions.is_empty() {
-            config::rebuild_shims_and_runtime_symlinks(&versions).await?;
+            let ts = config.get_toolset().await?;
+            config::rebuild_shims_and_runtime_symlinks(config, ts, &versions).await?;
         }
         Ok(versions)
     }
@@ -233,14 +238,14 @@ impl Toolset {
     #[async_backtrace::framed]
     pub async fn install_all_versions(
         &mut self,
-        config: &Arc<Config>,
+        config: &mut Arc<Config>,
         mut versions: Vec<ToolRequest>,
         opts: &InstallOptions,
     ) -> Result<Vec<ToolVersion>> {
         if versions.is_empty() {
             return Ok(vec![]);
         }
-        hooks::run_one_hook(self, Hooks::Preinstall, None).await;
+        hooks::run_one_hook(config, self, Hooks::Preinstall, None).await;
         self.init_request_options(&mut versions);
         show_python_install_hint(&versions);
         let mut installed = vec![];
@@ -254,8 +259,9 @@ impl Toolset {
             leaf_deps = get_leaf_dependencies(&versions)?;
         }
 
+        trace!("install: reloading config");
+        *config = Config::reset().await?;
         trace!("install: resolving");
-        // TODO: do I neeed this? backend::reset().await?;
         if let Err(err) = self.resolve(config).await {
             debug!("error resolving versions after install: {err:#}");
         }
@@ -263,7 +269,7 @@ impl Toolset {
             for tv in installed.iter() {
                 let backend = tv.backend()?;
                 let bin_paths = backend
-                    .list_bin_paths(tv)
+                    .list_bin_paths(config, tv)
                     .await
                     .map_err(|e| {
                         warn!("Error listing bin paths for {tv}: {e:#}");
@@ -282,7 +288,7 @@ impl Toolset {
                 }
             }
         }
-        hooks::run_one_hook(self, Hooks::Postinstall, None).await;
+        hooks::run_one_hook(config, self, Hooks::Postinstall, None).await;
         Ok(installed)
     }
 
@@ -304,20 +310,24 @@ impl Toolset {
             if let Some(plugin) = backend.plugin() {
                 if !plugin.is_installed() {
                     let mpr = MultiProgressReport::get();
-                    plugin.ensure_installed(&mpr, false).await.or_else(|err| {
-                        if let Some(&Error::PluginNotInstalled(_)) = err.downcast_ref::<Error>() {
-                            Ok(())
-                        } else {
-                            Err(err)
-                        }
-                    })?;
+                    plugin
+                        .ensure_installed(config, &mpr, false)
+                        .await
+                        .or_else(|err| {
+                            if let Some(&Error::PluginNotInstalled(_)) = err.downcast_ref::<Error>()
+                            {
+                                Ok(())
+                            } else {
+                                Err(err)
+                            }
+                        })?;
                 }
             }
         }
-        let raw = opts.raw || SETTINGS.raw;
+        let raw = opts.raw || Settings::get().raw;
         let jobs = match raw {
             true => 1,
-            false => opts.jobs.unwrap_or(SETTINGS.jobs),
+            false => opts.jobs.unwrap_or(Settings::get().jobs),
         };
         let semaphore = Arc::new(Semaphore::new(jobs));
         let ts = Arc::new(self.clone());
@@ -325,12 +335,12 @@ impl Toolset {
         let opts = Arc::new(opts.clone());
         for (ba, trs) in queue {
             let ts = ts.clone();
-            let semaphore = semaphore.clone();
+            let permit = semaphore.clone().acquire_owned().await?;
             let opts = opts.clone();
             let ba = ba.clone();
             let config = config.clone();
             tset.spawn(async move {
-                let _permit = semaphore.acquire().await?;
+                let _permit = permit;
                 let mpr = MultiProgressReport::get();
                 let mut installed = vec![];
                 for tr in trs {
@@ -456,30 +466,40 @@ impl Toolset {
         config: &Arc<Config>,
         bump: bool,
     ) -> Vec<OutdatedInfo> {
-        let mut outdated = vec![];
-        for (t, tv) in self.list_current_versions().into_iter() {
-            match t.outdated_info(config, &tv, bump).await {
+        let versions = self.list_current_versions();
+        let versions = versions
+            .into_iter()
+            .map(|(t, tv)| (config.clone(), t, tv, bump))
+            .collect::<Vec<_>>();
+        let outdated = parallel::parallel(versions, |(config, t, tv, bump)| async move {
+            let mut outdated = vec![];
+            match t.outdated_info(&config, &tv, bump).await {
                 Ok(Some(oi)) => outdated.push(oi),
                 Ok(None) => {}
                 Err(e) => {
                     warn!("Error getting outdated info for {tv}: {e:#}");
-                    continue;
                 }
             }
             if t.symlink_path(&tv).is_some() {
                 trace!("skipping symlinked version {tv}");
                 // do not consider symlinked versions to be outdated
-                continue;
+                return Ok(outdated);
             }
-            match OutdatedInfo::resolve(config, tv.clone(), bump).await {
+            match OutdatedInfo::resolve(&config, tv.clone(), bump).await {
                 Ok(Some(oi)) => outdated.push(oi),
                 Ok(None) => {}
                 Err(e) => {
                     warn!("Error creating OutdatedInfo for {tv}: {e:#}");
                 }
             }
-        }
-        outdated
+            Ok(outdated)
+        })
+        .await
+        .unwrap_or_else(|e| {
+            warn!("Error in parallel outdated version check: {e:#}");
+            vec![]
+        });
+        outdated.into_iter().flatten().collect()
     }
     /// returns env_with_path but also with the existing env vars from the system
     pub async fn full_env(&self, config: &Arc<Config>) -> Result<EnvMap> {
@@ -580,7 +600,7 @@ impl Toolset {
     pub async fn list_paths(&self, config: &Arc<Config>) -> Vec<PathBuf> {
         let mut paths = vec![];
         for (p, tv) in self.list_current_installed_versions(config).into_iter() {
-            paths.extend(p.list_bin_paths(&tv).await.unwrap_or_else(|e| {
+            paths.extend(p.list_bin_paths(config, &tv).await.unwrap_or_else(|e| {
                 warn!("Error listing bin paths for {tv}: {e:#}");
                 Vec::new()
             }));
@@ -634,7 +654,7 @@ impl Toolset {
         bin_name: &str,
     ) -> Option<(Arc<dyn Backend>, ToolVersion)> {
         for (p, tv) in self.list_current_installed_versions(config) {
-            match Box::pin(p.which(&tv, bin_name)).await {
+            match Box::pin(p.which(config, &tv, bin_name)).await {
                 Ok(Some(_bin)) => return Some((p, tv)),
                 Ok(None) => {}
                 Err(e) => {
@@ -646,16 +666,19 @@ impl Toolset {
     }
     pub async fn which_bin(&self, config: &Arc<Config>, bin_name: &str) -> Option<PathBuf> {
         let (p, tv) = Box::pin(self.which(config, bin_name)).await?;
-        Box::pin(p.which(&tv, bin_name)).await.ok().flatten()
+        Box::pin(p.which(config, &tv, bin_name))
+            .await
+            .ok()
+            .flatten()
     }
     pub async fn install_missing_bin(
         &mut self,
-        config: &Arc<Config>,
+        config: &mut Arc<Config>,
         bin_name: &str,
     ) -> Result<Option<Vec<ToolVersion>>> {
         let mut plugins = IndexSet::new();
         for (p, tv) in self.list_current_installed_versions(config) {
-            if let Ok(Some(_bin)) = p.which(&tv, bin_name).await {
+            if let Ok(Some(_bin)) = p.which(config, &tv, bin_name).await {
                 plugins.insert(p);
             }
         }
@@ -665,7 +688,7 @@ impl Toolset {
                 .await
                 .into_iter()
                 .filter(|tv| tv.ba() == &**plugin.ba())
-                .filter(|tv| match &SETTINGS.auto_install_disable_tools {
+                .filter(|tv| match &Settings::get().auto_install_disable_tools {
                     Some(disable_tools) => !disable_tools.contains(&tv.ba().short),
                     None => true,
                 })
@@ -676,7 +699,8 @@ impl Toolset {
                     .install_all_versions(config, versions.clone(), &InstallOptions::default())
                     .await?;
                 if !versions.is_empty() {
-                    config::rebuild_shims_and_runtime_symlinks(&versions).await?;
+                    let ts = config.get_toolset().await?;
+                    config::rebuild_shims_and_runtime_symlinks(config, ts, &versions).await?;
                 }
                 return Ok(Some(versions));
             }
@@ -691,7 +715,7 @@ impl Toolset {
     ) -> Result<Vec<ToolVersion>> {
         let mut rtvs = vec![];
         for (p, tv) in self.list_installed_versions(config).await? {
-            match p.which(&tv, bin_name).await {
+            match p.which(config, &tv, bin_name).await {
                 Ok(Some(_bin)) => rtvs.push(tv),
                 Ok(None) => {}
                 Err(e) => {
@@ -706,13 +730,13 @@ impl Toolset {
     // only displays for tools which have at least one version already installed
     #[async_backtrace::framed]
     pub async fn notify_if_versions_missing(&self, config: &Arc<Config>) {
-        if SETTINGS.status.missing_tools() == SettingsStatusMissingTools::Never {
+        if Settings::get().status.missing_tools() == SettingsStatusMissingTools::Never {
             return;
         }
         let mut missing = vec![];
         let missing_versions = self.list_missing_versions(config).await;
         for tv in missing_versions.into_iter() {
-            if SETTINGS.status.missing_tools() == SettingsStatusMissingTools::Always {
+            if Settings::get().status.missing_tools() == SettingsStatusMissingTools::Always {
                 missing.push(tv);
                 continue;
             }
@@ -740,8 +764,8 @@ impl Toolset {
     fn is_disabled(&self, ba: &BackendArg) -> bool {
         !ba.is_os_supported()
             || !tool_enabled(
-                &SETTINGS.enable_tools(),
-                &SETTINGS.disable_tools(),
+                &Settings::get().enable_tools(),
+                &Settings::get().disable_tools(),
                 &ba.short.to_string(),
             )
     }
