@@ -1,6 +1,6 @@
 use crate::cli::args::BackendArg;
 use crate::cmd::CmdLineRunner;
-use crate::config::{Config, SETTINGS};
+use crate::config::{Config, Settings};
 use crate::ui::multi_progress_report::MultiProgressReport;
 use crate::{dirs, file};
 use eyre::Result;
@@ -23,12 +23,12 @@ pub async fn uv_venv(config: &Arc<Config>) -> Option<Venv> {
     if let Some(venv) = UV_VENV.get() {
         return venv.clone();
     }
-    if !SETTINGS.python.uv_venv_auto {
+    if !Settings::get().python.uv_venv_auto {
         UV_VENV.set(None).unwrap();
         return None;
     }
     if let (Some(venv_path), Some(uv_path)) = (venv_path(), uv_path(config).await) {
-        match get_or_create_venv(venv_path, uv_path).await {
+        match get_or_create_venv(config, venv_path, uv_path).await {
             Ok(venv) => {
                 UV_VENV.set(Some(venv.clone())).unwrap();
                 return Some(venv);
@@ -42,14 +42,17 @@ pub async fn uv_venv(config: &Arc<Config>) -> Option<Venv> {
     None
 }
 
-async fn get_or_create_venv(venv_path: PathBuf, uv_path: PathBuf) -> Result<Venv> {
-    SETTINGS.ensure_experimental("uv venv auto")?;
+async fn get_or_create_venv(
+    config: &Arc<Config>,
+    venv_path: PathBuf,
+    uv_path: PathBuf,
+) -> Result<Venv> {
+    Settings::get().ensure_experimental("uv venv auto")?;
     let mut venv = Venv {
         env: Default::default(),
         venv_path: venv_path.join("bin"),
     };
-    if let Some(python_tv) = Config::get()
-        .await
+    if let Some(python_tv) = config
         .get_toolset()
         .await?
         .versions
